Function open_working_directory_pool

pub fn open_working_directory_pool(
    conf: &RunConfig,
    base_dir: Arc<WorkingDirectoryPoolBaseDir>,
    omit_check: bool,
    signal_change: Option<PollingSignalsSender>,
) -> Result<WorkingDirectoryPoolAndLock>
Takes base_dir since it needs to be constructed from what’s in conf and GlobalAppStateDir, which is done way up in main, so we receive it from there, and we ignore the partially-duplicate piece of data in conf.